@@ -1,11 +1,16 @@
 import typing
 from datetime import timedelta
 
+import chardet
 import pytest
 
 import httpx
 
 
+def autodetect(content):
+    return chardet.detect(content).get("encoding")
+
+
 def test_get(server):
     url = server.url
     with httpx.Client(http2=True) as http:
@@ -15,7 +20,7 @@ def test_get(server):
     assert response.content == b"Hello, world!"
     assert response.text == "Hello, world!"
     assert response.http_version == "HTTP/1.1"
-    assert response.encoding is None
+    assert response.encoding == "utf-8"
     assert response.request.url == url
     assert response.headers
     assert response.is_redirect is False
@@ -398,3 +403,58 @@ def test_server_extensions(server):
         response = client.get(url)
     assert response.status_code == 200
     assert response.extensions["http_version"] == b"HTTP/1.1"
+
+
+def test_client_decode_text_using_autodetect():
+    # Ensure that a 'default_encoding=autodetect' on the response allows for
+    # encoding autodetection to be used when no "Content-Type: text/plain; charset=..."
+    # info is present.
+    #
+    # Here we have some french text encoded with ISO-8859-1, rather than UTF-8.
+    text = (
+        "Non-seulement Despréaux ne se trompait pas, mais de tous les écrivains "
+        "que la France a produits, sans excepter Voltaire lui-même, imprégné de "
+        "l'esprit anglais par son séjour à Londres, c'est incontestablement "
+        "Molière ou Poquelin qui reproduit avec l'exactitude la plus vive et la "
+        "plus complète le fond du génie français."
+    )
+
+    def cp1252_but_no_content_type(request):
+        content = text.encode("ISO-8859-1")
+        return httpx.Response(200, content=content)
+
+    transport = httpx.MockTransport(cp1252_but_no_content_type)
+    with httpx.Client(transport=transport, default_encoding=autodetect) as client:
+        response = client.get("http://www.example.com")
+
+        assert response.status_code == 200
+        assert response.reason_phrase == "OK"
+        assert response.encoding == "ISO-8859-1"
+        assert response.text == text
+
+
+def test_client_decode_text_using_explicit_encoding():
+    # Ensure that a 'default_encoding="..."' on the response is used for text decoding
+    # when no "Content-Type: text/plain; charset=..."" info is present.
+    #
+    # Here we have some french text encoded with ISO-8859-1, rather than UTF-8.
+    text = (
+        "Non-seulement Despréaux ne se trompait pas, mais de tous les écrivains "
+        "que la France a produits, sans excepter Voltaire lui-même, imprégné de "
+        "l'esprit anglais par son séjour à Londres, c'est incontestablement "
+        "Molière ou Poquelin qui reproduit avec l'exactitude la plus vive et la "
+        "plus complète le fond du génie français."
+    )
+
+    def cp1252_but_no_content_type(request):
+        content = text.encode("ISO-8859-1")
+        return httpx.Response(200, content=content)
+
+    transport = httpx.MockTransport(cp1252_but_no_content_type)
+    with httpx.Client(transport=transport, default_encoding=autodetect) as client:
+        response = client.get("http://www.example.com")
+
+        assert response.status_code == 200
+        assert response.reason_phrase == "OK"
+        assert response.encoding == "ISO-8859-1"
+        assert response.text == text
